@@ -36,7 +36,7 @@ class MainWindow : public LXQt::ConfigDialog
     Q_OBJECT
 
 public:
-    explicit MainWindow(QWidget* parent = 0);
+    explicit MainWindow(QWidget* parent = nullptr);
     ~MainWindow();
 
 };
