@@ -112,8 +112,8 @@
         <location filename="../basicsettings.cpp" line="65"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
 Keep trying to connect…</source>
-        <translation>&lt;b&gt;Warnung:&lt;/b&gt; Nachrichtenservice antwortet langsam.
-Versuche zu verbinden…</translation>
+        <translation>&lt;b&gt;Warnung &lt;/b&gt;: Der Benachrichtigungsdämon benötigt zu
+ lange zum antworten. Versuche zu verbinden…</translation>
     </message>
     <message>
         <location filename="../basicsettings.cpp" line="74"/>
@@ -197,7 +197,7 @@ Alle Benachrichtigungen erscheinen jetzt hier auf LXQt.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
         <source>Appearance</source>
-        <translation type="unfinished"></translation>
+        <translation>Erscheinungsbild</translation>
     </message>
 </context>
 </TS>
