@@ -5,67 +5,46 @@
     <name>AdvancedSettings</name>
     <message>
         <location filename="../advancedsettings.ui" line="67"/>
-        <source>Sizes</source>
-        <translation>Medidas</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="75"/>
-        <source>Width:</source>
-        <translation>Ancho:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="82"/>
-        <location filename="../advancedsettings.ui" line="106"/>
-        <source> px</source>
-        <translation> px</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="99"/>
-        <source>Spacing:</source>
-        <translation>Espaciado:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="118"/>
         <source>Duration</source>
         <translation>Duración</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="130"/>
+        <location filename="../advancedsettings.ui" line="79"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Algunas notificaciones establecen su propia duración en pantalla.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="142"/>
+        <location filename="../advancedsettings.ui" line="91"/>
         <source>Default duration:</source>
         <translation>Duración por defecto:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="149"/>
+        <location filename="../advancedsettings.ui" line="98"/>
         <source> sec</source>
         <translation> s</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="177"/>
+        <location filename="../advancedsettings.ui" line="126"/>
         <source>Screen</source>
         <translation>Pantalla</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="183"/>
+        <location filename="../advancedsettings.ui" line="132"/>
         <source>When unchecked the notification will always show on primary screen</source>
         <translation>Al deseleccionar, la notificación siempre aparecerá en la ventana principal</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="186"/>
+        <location filename="../advancedsettings.ui" line="135"/>
         <source>Show notifications on screen with the mouse</source>
         <translation>Mostrar notificaciones en pantalla con el mouse</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="196"/>
+        <location filename="../advancedsettings.ui" line="145"/>
         <source>Do Not Disturb</source>
         <translation>No molestar</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="202"/>
+        <location filename="../advancedsettings.ui" line="151"/>
         <source>Only save notifications</source>
         <translation>Guardar solo notificaciones</translation>
     </message>
@@ -100,82 +79,103 @@
     <name>BasicSettings</name>
     <message>
         <location filename="../basicsettings.ui" line="17"/>
+        <source>Sizes</source>
+        <translation>Medidas</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="25"/>
+        <source>Width:</source>
+        <translation>Ancho:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="32"/>
+        <location filename="../basicsettings.ui" line="56"/>
+        <source> px</source>
+        <translation> px</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="49"/>
+        <source>Spacing:</source>
+        <translation>Espaciado:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="68"/>
         <source>Position on screen</source>
         <translation>Posición en la pantalla</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="176"/>
+        <location filename="../basicsettings.ui" line="227"/>
         <source>Preview</source>
         <translation>Vista previa</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="63"/>
+        <location filename="../basicsettings.cpp" line="65"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
 Keep trying to connect…</source>
         <translation>Advertencia: el servicio de notificaciones se tarda en responder.
 Continúa tratando de conectarse…</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="72"/>
+        <location filename="../basicsettings.cpp" line="74"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Aviso:&lt;/b&gt; no hay ningún demonio de notificaciones en ejecución.
 Se usará un medio alternativo.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="75"/>
+        <location filename="../basicsettings.cpp" line="77"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Aviso:&lt;/b&gt; un demonio de notificaciones de terceros (%1) está en ejecución.
 ¡Estos ajustes no tendrán ningún efecto sobre él!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="137"/>
+        <location filename="../basicsettings.cpp" line="142"/>
         <source>at top left</source>
         <translation>arriba a la izquierda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="139"/>
+        <location filename="../basicsettings.cpp" line="144"/>
         <source>at top center</source>
         <translation>arriba en el centro</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="141"/>
+        <location filename="../basicsettings.cpp" line="146"/>
         <source>at top right</source>
         <translation>arriba a la derecha</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="143"/>
+        <location filename="../basicsettings.cpp" line="148"/>
         <source>at center left</source>
         <translation>en el centro a la izquierda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="145"/>
+        <location filename="../basicsettings.cpp" line="150"/>
         <source>at center right</source>
         <translation>en el centro a la derecha</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="147"/>
+        <location filename="../basicsettings.cpp" line="152"/>
         <source>at bottom left</source>
         <translation>abajo a la izquierda</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="149"/>
+        <location filename="../basicsettings.cpp" line="154"/>
         <source>at bottom center</source>
         <translation>abajo en el centro</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="151"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>at bottom right</source>
         <translation>abajo a la derecha</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="153"/>
+        <location filename="../basicsettings.cpp" line="158"/>
         <source>Notification demo </source>
         <translation>Demostración de notificación </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="154"/>
+        <location filename="../basicsettings.cpp" line="159"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Esto es una notificación de prueba
@@ -196,8 +196,8 @@ These settings won&apos;t have any effect on it!</source>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
-        <source>Position</source>
-        <translation>Posición</translation>
+        <source>Appearance</source>
+        <translation>Aspecto</translation>
     </message>
 </context>
 </TS>
