@@ -4,32 +4,22 @@
 <context>
     <name>AdvancedSettings</name>
     <message>
-        <location filename="../advancedsettings.ui" line="75"/>
-        <source>Width:</source>
-        <translation>Larghezza:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="99"/>
-        <source>Spacing:</source>
-        <translation>Distanza:</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="118"/>
+        <location filename="../advancedsettings.ui" line="67"/>
         <source>Duration</source>
         <translation>Durata</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="130"/>
+        <location filename="../advancedsettings.ui" line="79"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Alcune notifiche impostano una durata propria.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="142"/>
+        <location filename="../advancedsettings.ui" line="91"/>
         <source>Default duration:</source>
         <translation>Durata di default:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="149"/>
+        <location filename="../advancedsettings.ui" line="98"/>
         <source> sec</source>
         <translation> sec</translation>
     </message>
@@ -60,38 +50,27 @@
         <translation>app1,app2,app3</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="67"/>
-        <source>Sizes</source>
-        <translation>Dimensioni</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="82"/>
-        <location filename="../advancedsettings.ui" line="106"/>
-        <source> px</source>
-        <translation> px</translation>
-    </message>
-    <message>
-        <location filename="../advancedsettings.ui" line="177"/>
+        <location filename="../advancedsettings.ui" line="126"/>
         <source>Screen</source>
         <translation>Monitor</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="183"/>
+        <location filename="../advancedsettings.ui" line="132"/>
         <source>When unchecked the notification will always show on primary screen</source>
         <translation>Se non è spuntata le notifiche appariranno sempre sul monitor primario</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="186"/>
+        <location filename="../advancedsettings.ui" line="135"/>
         <source>Show notifications on screen with the mouse</source>
         <translation>Mostra le notifiche sul monitor con il cursore</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="196"/>
+        <location filename="../advancedsettings.ui" line="145"/>
         <source>Do Not Disturb</source>
         <translation>Non disturbare</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="202"/>
+        <location filename="../advancedsettings.ui" line="151"/>
         <source>Only save notifications</source>
         <translation>Salva soltanto le notifiche</translation>
     </message>
@@ -100,82 +79,103 @@
     <name>BasicSettings</name>
     <message>
         <location filename="../basicsettings.ui" line="17"/>
+        <source>Sizes</source>
+        <translation>Dimensioni</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="25"/>
+        <source>Width:</source>
+        <translation>Larghezza:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="32"/>
+        <location filename="../basicsettings.ui" line="56"/>
+        <source> px</source>
+        <translation> px</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="49"/>
+        <source>Spacing:</source>
+        <translation>Distanza:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="68"/>
         <source>Position on screen</source>
         <translation>Posizione sullo schermo</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="176"/>
+        <location filename="../basicsettings.ui" line="227"/>
         <source>Preview</source>
         <translation>Anteprima</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="63"/>
+        <location filename="../basicsettings.cpp" line="65"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
 Keep trying to connect…</source>
         <translation>&lt;b&gt;Attenzione:&lt;/b&gt; il demone delle notifiche è lento a rispondere
 Provando a connettere…</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="72"/>
+        <location filename="../basicsettings.cpp" line="74"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Attenzione:&lt;/b&gt; Nessun demone di notifiche è in esecuzione.
 Sarà usato un sistema di riserva.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="75"/>
+        <location filename="../basicsettings.cpp" line="77"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Avviso:&lt;/b&gt; Un altro demone di notifiche (%1) è attivo.
 Queste impostazioni non avranno effetto per esso!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="137"/>
+        <location filename="../basicsettings.cpp" line="142"/>
         <source>at top left</source>
         <translation>in cima a sinistra</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="139"/>
+        <location filename="../basicsettings.cpp" line="144"/>
         <source>at top center</source>
         <translation>in cima al centro</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="141"/>
+        <location filename="../basicsettings.cpp" line="146"/>
         <source>at top right</source>
         <translation>in cima a destra</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="143"/>
+        <location filename="../basicsettings.cpp" line="148"/>
         <source>at center left</source>
-        <translation>a destra al centro</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.cpp" line="145"/>
-        <source>at center right</source>
         <translation>a sinistra al centro</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="147"/>
+        <location filename="../basicsettings.cpp" line="150"/>
+        <source>at center right</source>
+        <translation>a destra al centro</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="152"/>
         <source>at bottom left</source>
         <translation>in fondo a sinistra</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="149"/>
+        <location filename="../basicsettings.cpp" line="154"/>
         <source>at bottom center</source>
         <translation>in fondo al centro</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="151"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>at bottom right</source>
         <translation>in fondo a destra</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="153"/>
+        <location filename="../basicsettings.cpp" line="158"/>
         <source>Notification demo </source>
         <translation>Anteprima notifiche </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="154"/>
+        <location filename="../basicsettings.cpp" line="159"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Questo è una notifica di test.
@@ -196,8 +196,8 @@ Tutte le notifiche di LXQt appariranno qui.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="48"/>
-        <source>Position</source>
-        <translation>Posizione</translation>
+        <source>Appearance</source>
+        <translation>Aspetto</translation>
     </message>
 </context>
 </TS>
